#!/usr/bin/env python
import pygame
from pygame.locals import *
import sys

import cursor, tools

SCR_RECT = Rect(0, 0, 640, 480)

class Main():
    def __init__(self):
        pygame.init()
        pygame.display.set_caption("sample")
        screen = pygame.display.set_mode(SCR_RECT.size)

        self.font = pygame.font.Font("data/minamoji04.ttf", 80)
        self.title = self.font.render("ラビップルの冒険", True, (0, 0, 0))
        self.start = self.font.render("はじめる", True, (0, 0, 0))

        # アニメーション
        self.frame = 0
        self.animecycle = 24
        # ラビップルの向き（0が左向き、1が右向き）
        self.direction = 0

        # 画像をロードし、分割する
        self.images = tools.split_image(tools.load_image("data", "rabipple.png"), 2, 2)
        self.image = self.images[0]
        self.x = 288
        self.y = 200
        self.speed = 5

        self.bg = tools.load_image("data", "bg.png")

        self.cursor = cursor.Cursor(90, 330, (0, 0, 0))

        clock = pygame.time.Clock()
        while True:
            clock.tick(30)
            self.update()
            self.draw(screen)
            pygame.display.update()
            self.key_handler()

    def update(self):
        self.cursor.update()
        self.frame += 1
        # 画像を切り替える
        self.image = self.images[(self.direction * 2) + int(self.frame / self.animecycle % 2)]

    def draw(self, screen):
        screen.blit(self.bg, (0, 0))

        screen.blit(self.title, (((320 - (self.title.get_width() / 2)), 100)))
        screen.blit(self.start, (((320 - (self.start.get_width() / 2)), 300)))
        screen.blit(self.image, (self.x, self.y))

        self.cursor.draw(screen)

    def key_handler(self):
        for event in pygame.event.get():
            if event.type == QUIT:
                pygame.quit()
                sys.exit()
        pressed_keys = pygame.key.get_pressed()
        if pressed_keys[K_LEFT]:
            self.frame += 1
            # 向きを左向きに
            self.direction = 0
            self.x -= self.speed
        if pressed_keys[K_RIGHT]:
            self.frame += 1
            # 向きを右向きに
            self.direction = 1
            self.x += self.speed
        if pressed_keys[K_UP]:
            self.frame += 1
            self.y -= self.speed
        if pressed_keys[K_DOWN]:
            self.frame += 1
            self.y += self.speed

if __name__ == "__main__":
    Main()
